@@ -4,6 +4,11 @@ import stretch_body.hello_utils as hello_utils
 import importlib
 import stretch_body.robot_params
 
+import argparse
+parser=argparse.ArgumentParser(description='Print the Stretch parameters to the console')
+args=parser.parse_args()
+
+
 """
 Print out the robot parameters to the command line, 
 including where each parameter value originates from
@@ -17,21 +22,23 @@ def build_rep(prefix, params, origin,rep):
             rep[np]=[params[k], origin]
     return rep
 
-rep={}
-user_origin='stretch_re1_user_params.yaml'
+rp=stretch_body.robot_params.RobotParams()
+
+user_origin='stretch_user_params.yaml'
 user_params = hello_utils.read_fleet_yaml(user_origin)
 
-factory_origin=user_params['factory_params']
-factory_params=hello_utils.read_fleet_yaml(factory_origin)
-build_rep('param',factory_params,factory_origin,rep)
+rep={}
+build_rep('param',stretch_body.robot_params.nominal_system_params,'stretch_body.robot_params.nominal_system_params',rep)
+build_rep('param',rp._nominal_params,'stretch_body.robot_params.nominal_params',rep)
 
-factory_origin='stretch_body.robot_params.factory_params'
-build_rep('param',stretch_body.robot_params.factory_params,factory_origin,rep)
-
-for outside_params_origin in user_params.get('params', []):
+for outside_params_origin in rp._user_params.get('params', []):
     outside_params=getattr(importlib.import_module(outside_params_origin),'params')
     build_rep('param', outside_params, outside_params_origin, rep)
 
+config_origin='stretch_configuration_params.yaml'
+config_params=hello_utils.read_fleet_yaml(config_origin)
+build_rep('param',config_params,config_origin,rep)
+
 build_rep('param',user_params,user_origin,rep)
 
 print('#'*60+ ' Parameters for %s '%hello_utils.get_fleet_id()+'#'*60)
@@ -39,4 +46,3 @@ print ("{:<70} {:<70} {:<30}".format('Origin','Parameter','Value'))
 print('-'*170)
 for param in rep.keys():
     print("{:<70} {:<70} {:<30}".format(str(rep[param][1]), param, str(rep[param][0] )))
-
